==> seedsui-react-5.6.85.tgz: package/lib/TreePicker/Tree/index.js <==
function _typeof(obj) { "@babel/helpers - typeof"; return _typeof = "function" == typeof Symbol && "symbol" == typeof Symbol.iterator ? function (obj) { return typeof obj; } : function (obj) { return obj && "function" == typeof Symbol && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }, _typeof(obj); }
var _excluded = ["multiple", "checkStrictly", "onlyLeafCheck", "checkable", "selectable", "list", "defaultValue", "value", "throttle", "onChange", "showIcon", "itemRender"];
function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); enumerableOnly && (symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; })), keys.push.apply(keys, symbols); } return keys; }
function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = null != arguments[i] ? arguments[i] : {}; i % 2 ? ownKeys(Object(source), !0).forEach(function (key) { _defineProperty(target, key, source[key]); }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)) : ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } return target; }
function _defineProperty(obj, key, value) { key = _toPropertyKey(key); if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }
function _toPropertyKey(arg) { var key = _toPrimitive(arg, "string"); return _typeof(key) === "symbol" ? key : String(key); }
function _toPrimitive(input, hint) { if (_typeof(input) !== "object" || input === null) return input; var prim = input[Symbol.toPrimitive]; if (prim !== undefined) { var res = prim.call(input, hint || "default"); if (_typeof(res) !== "object") return res; throw new TypeError("@@toPrimitive must return a primitive value."); } return (hint === "string" ? String : Number)(input); }
function _toConsumableArray(arr) { return _arrayWithoutHoles(arr) || _iterableToArray(arr) || _unsupportedIterableToArray(arr) || _nonIterableSpread(); }
function _nonIterableSpread() { throw new TypeError("Invalid attempt to spread non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method."); }
function _iterableToArray(iter) { if (typeof Symbol !== "undefined" && iter[Symbol.iterator] != null || iter["@@iterator"] != null) return Array.from(iter); }
function _arrayWithoutHoles(arr) { if (Array.isArray(arr)) return _arrayLikeToArray(arr); }
function _slicedToArray(arr, i) { return _arrayWithHoles(arr) || _iterableToArrayLimit(arr, i) || _unsupportedIterableToArray(arr, i) || _nonIterableRest(); }
function _nonIterableRest() { throw new TypeError("Invalid attempt to destructure non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method."); }
function _unsupportedIterableToArray(o, minLen) { if (!o) return; if (typeof o === "string") return _arrayLikeToArray(o, minLen); var n = Object.prototype.toString.call(o).slice(8, -1); if (n === "Object" && o.constructor) n = o.constructor.name; if (n === "Map" || n === "Set") return Array.from(o); if (n === "Arguments" || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)) return _arrayLikeToArray(o, minLen); }
function _arrayLikeToArray(arr, len) { if (len == null || len > arr.length) len = arr.length; for (var i = 0, arr2 = new Array(len); i < len; i++) arr2[i] = arr[i]; return arr2; }
function _iterableToArrayLimit(arr, i) { var _i = null == arr ? null : "undefined" != typeof Symbol && arr[Symbol.iterator] || arr["@@iterator"]; if (null != _i) { var _s, _e, _x, _r, _arr = [], _n = !0, _d = !1; try { if (_x = (_i = _i.call(arr)).next, 0 === i) { if (Object(_i) !== _i) return; _n = !1; } else for (; !(_n = (_s = _x.call(_i)).done) && (_arr.push(_s.value), _arr.length !== i); _n = !0); } catch (err) { _d = !0, _e = err; } finally { try { if (!_n && null != _i.return && (_r = _i.return(), Object(_r) !== _r)) return; } finally { if (_d) throw _e; } } return _arr; } }
function _arrayWithHoles(arr) { if (Array.isArray(arr)) return arr; }
function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }
function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }
import React, { forwardRef, useImperativeHandle, useEffect, useMemo, useState, useRef } from 'react';
import { getTreeData, getExpandedKeys, getCheckedKeysProp, getLoadedKeys } from "./utils/index";
import Tree from 'rc-tree';

// 树控件
import { jsx as _jsx } from "react/jsx-runtime";
import { Fragment as _Fragment } from "react/jsx-runtime";
function TreePicker(_ref, ref) {
  var multiple = _ref.multiple,
    _ref$checkStrictly = _ref.checkStrictly,
    checkStrictly = _ref$checkStrictly === void 0 ? false : _ref$checkStrictly,
    onlyLeafCheck = _ref.onlyLeafCheck,
    _ref$checkable = _ref.checkable,
    checkable = _ref$checkable === void 0 ? true : _ref$checkable,
    selectable = _ref.selectable,
    list = _ref.list,
    defaultValue = _ref.defaultValue,
    value = _ref.value,
    _ref$throttle = _ref.throttle,
    throttle = _ref$throttle === void 0 ? 500 : _ref$throttle,
    onChange = _ref.onChange,
    _ref$showIcon = _ref.showIcon,
    showIcon = _ref$showIcon === void 0 ? false : _ref$showIcon,
    itemRender = _ref.itemRender,
    props = _objectWithoutProperties(_ref, _excluded);
  var treeRef = useRef(null);
  useImperativeHandle(ref, function () {
    return {
      instance: treeRef.current,
      search: search
    };
  });

  // 扁平化数据, 搜索时需要展开的子级
  var flattenListRef = useRef(null);

  // 搜索关键字
  var keywordRef = useRef(null);

  // 树渲染数据
  var _useState = useState(null),
    _useState2 = _slicedToArray(_useState, 2),
    treeData = _useState2[0],
    setTreeData = _useState2[1];

  // 展开的id
  var _useState3 = useState([]),
    _useState4 = _slicedToArray(_useState3, 2),
    expandedKeys = _useState4[0],
    setExpandedKeys = _useState4[1];

  // 异步已加载项(去掉小箭头项), 只有传入loadData时才生效
  var _useState5 = useState([]),
    _useState6 = _slicedToArray(_useState5, 2),
    loadedKeys = _useState6[0],
    setLoadedKeys = _useState6[1];

  // 更新列表
  useEffect(function () {
    if (!Array.isArray(list) || !list.length) return;

    // 更新平铺的列表, 搜索时使用
    flattenListRef.current = Object.clone(list).flattenTree();

    // 更新渲染列表
    setTreeData(getTreeData({
      list: list,
      onlyLeafCheck: onlyLeafCheck,
      keyword: keywordRef.current || '',
      itemRender: itemRender
    }));
    // eslint-disable-next-line
  }, [list]);

  // 展开关键字
  function search(keyword) {
    keywordRef.current = keyword;
    // 没有关键字则没有展开项
    if (!keywordRef.current || Object.isEmptyObject(list)) {
      setExpandedKeys([]);
    } else {
      // 展开的keys
      var newExpandedKeys = getExpandedKeys(keywordRef.current, flattenListRef.current);
      setExpandedKeys(newExpandedKeys);
    }

    // 更新渲染列表
    setTreeData(getTreeData({
      list: list,
      onlyLeafCheck: onlyLeafCheck,
      keyword: keywordRef.current || '',
      itemRender: itemRender
    }));
  }

  // 修改
  function handleChange(ids, checkedObject) {
    var checkedNodes = (checkedObject === null || checkedObject === void 0 ? void 0 : checkedObject.checkedNodes) || [];
    // multiple未传则为必选单选
    if (multiple === undefined) {
      if (checkedObject !== null && checkedObject !== void 0 && checkedObject.node) checkedNodes = [checkedObject.node];
    }
    // multiple为false时为可取消单选
    if (multiple === false) {
      if (checkedNodes.length > 1) {
        if (checkedObject !== null && checkedObject !== void 0 && checkedObject.node) checkedNodes = [checkedObject.node];
      }
    }
    if (onChange) onChange(checkedNodes);
  }

  // 构建选中项
  var checkedKeysProp = useMemo(function () {
    // defaultCheckedKeys|checkedKeys: checkedKeys
    return getCheckedKeysProp(value, defaultValue);
  }, [value, defaultValue]);

  // 构建搜索的展开项
  var expandProp = Array.isArray(expandedKeys) && expandedKeys.length ? {
    // 设置了expandedKeys, 就必须有配套的onExpand, 否则将不能再收缩了
    onExpand: function onExpand(newExpandedKeys) {
      setExpandedKeys(newExpandedKeys);
    },
    // 搜索时展开的子级
    expandedKeys: expandedKeys
  } : {};

  // 异步加载时需要判断哪些不需要再次加载(isLoaded)
  var loadProp = typeof props.loadData === 'function' ? {
    loadedKeys: loadedKeys,
    onLoad: function onLoad(loadedKeys) {
      loadedKeys.push.apply(loadedKeys, _toConsumableArray(getLoadedKeys(flattenListRef.current)));
      setLoadedKeys(_toConsumableArray(new Set(loadedKeys)));
    }
  } : {};
  if (!treeData) return null;
  return /*#__PURE__*/_jsx(_Fragment, {
    children: /*#__PURE__*/_jsx(Tree, _objectSpread(_objectSpread(_objectSpread(_objectSpread({
      ref: treeRef,
      fieldNames: {
        key: 'id'
      },
      treeData: treeData
      // 异步加载时需要判断哪些不需要再次加载
    }, loadProp), checkedKeysProp), {}, {
      // 选中checkbox
      onCheck: handleChange
      // 点击(用于解决checkable为false时没有checkbox时onChange)
      ,
      onSelect: handleChange
      // 展开keys属性
    }, expandProp), {}, {
      // 树默认设置
      showIcon: showIcon,
      onlyLeafCheck: onlyLeafCheck,
      checkStrictly: checkStrictly,
      checkable: checkable,
      selectable: checkable ? false : true
    }, props))
  });
}
export default /*#__PURE__*/forwardRef(TreePicker);

==> seedsui-react-5.6.96.tgz: package/lib/TreePicker/Tree/index.js <==
function _typeof(obj) { "@babel/helpers - typeof"; return _typeof = "function" == typeof Symbol && "symbol" == typeof Symbol.iterator ? function (obj) { return typeof obj; } : function (obj) { return obj && "function" == typeof Symbol && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }, _typeof(obj); }
var _excluded = ["multiple", "checkStrictly", "enableHalfChecked", "preserveValue", "onlyLeafCheck", "checkable", "selectable", "list", "defaultValue", "value", "throttle", "onChange", "onSelect", "showIcon", "itemRender"];
function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); enumerableOnly && (symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; })), keys.push.apply(keys, symbols); } return keys; }
function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = null != arguments[i] ? arguments[i] : {}; i % 2 ? ownKeys(Object(source), !0).forEach(function (key) { _defineProperty(target, key, source[key]); }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)) : ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } return target; }
function _defineProperty(obj, key, value) { key = _toPropertyKey(key); if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }
function _toPropertyKey(arg) { var key = _toPrimitive(arg, "string"); return _typeof(key) === "symbol" ? key : String(key); }
function _toPrimitive(input, hint) { if (_typeof(input) !== "object" || input === null) return input; var prim = input[Symbol.toPrimitive]; if (prim !== undefined) { var res = prim.call(input, hint || "default"); if (_typeof(res) !== "object") return res; throw new TypeError("@@toPrimitive must return a primitive value."); } return (hint === "string" ? String : Number)(input); }
function _createForOfIteratorHelper(o, allowArrayLike) { var it = typeof Symbol !== "undefined" && o[Symbol.iterator] || o["@@iterator"]; if (!it) { if (Array.isArray(o) || (it = _unsupportedIterableToArray(o)) || allowArrayLike && o && typeof o.length === "number") { if (it) o = it; var i = 0; var F = function F() {}; return { s: F, n: function n() { if (i >= o.length) return { done: true }; return { done: false, value: o[i++] }; }, e: function e(_e2) { throw _e2; }, f: F }; } throw new TypeError("Invalid attempt to iterate non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method."); } var normalCompletion = true, didErr = false, err; return { s: function s() { it = it.call(o); }, n: function n() { var step = it.next(); normalCompletion = step.done; return step; }, e: function e(_e3) { didErr = true; err = _e3; }, f: function f() { try { if (!normalCompletion && it.return != null) it.return(); } finally { if (didErr) throw err; } } }; }
function _toConsumableArray(arr) { return _arrayWithoutHoles(arr) || _iterableToArray(arr) || _unsupportedIterableToArray(arr) || _nonIterableSpread(); }
function _nonIterableSpread() { throw new TypeError("Invalid attempt to spread non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method."); }
function _iterableToArray(iter) { if (typeof Symbol !== "undefined" && iter[Symbol.iterator] != null || iter["@@iterator"] != null) return Array.from(iter); }
function _arrayWithoutHoles(arr) { if (Array.isArray(arr)) return _arrayLikeToArray(arr); }
function _slicedToArray(arr, i) { return _arrayWithHoles(arr) || _iterableToArrayLimit(arr, i) || _unsupportedIterableToArray(arr, i) || _nonIterableRest(); }
function _nonIterableRest() { throw new TypeError("Invalid attempt to destructure non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method."); }
function _unsupportedIterableToArray(o, minLen) { if (!o) return; if (typeof o === "string") return _arrayLikeToArray(o, minLen); var n = Object.prototype.toString.call(o).slice(8, -1); if (n === "Object" && o.constructor) n = o.constructor.name; if (n === "Map" || n === "Set") return Array.from(o); if (n === "Arguments" || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)) return _arrayLikeToArray(o, minLen); }
function _arrayLikeToArray(arr, len) { if (len == null || len > arr.length) len = arr.length; for (var i = 0, arr2 = new Array(len); i < len; i++) arr2[i] = arr[i]; return arr2; }
function _iterableToArrayLimit(arr, i) { var _i = null == arr ? null : "undefined" != typeof Symbol && arr[Symbol.iterator] || arr["@@iterator"]; if (null != _i) { var _s, _e, _x, _r, _arr = [], _n = !0, _d = !1; try { if (_x = (_i = _i.call(arr)).next, 0 === i) { if (Object(_i) !== _i) return; _n = !1; } else for (; !(_n = (_s = _x.call(_i)).done) && (_arr.push(_s.value), _arr.length !== i); _n = !0); } catch (err) { _d = !0, _e = err; } finally { try { if (!_n && null != _i.return && (_r = _i.return(), Object(_r) !== _r)) return; } finally { if (_d) throw _e; } } return _arr; } }
function _arrayWithHoles(arr) { if (Array.isArray(arr)) return arr; }
function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }
function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }
import React, { forwardRef, useImperativeHandle, useEffect, useMemo, useState, useRef } from 'react';
import { getTreeData, getExpandedKeys, getCheckedKeysProp, getLoadedKeys } from "./utils/index";
import Tree from 'rc-tree';

// 树控件
import { jsx as _jsx } from "react/jsx-runtime";
import { Fragment as _Fragment } from "react/jsx-runtime";
function TreePicker(_ref, ref) {
  var multiple = _ref.multiple,
    _ref$checkStrictly = _ref.checkStrictly,
    checkStrictly = _ref$checkStrictly === void 0 ? false : _ref$checkStrictly,
    enableHalfChecked = _ref.enableHalfChecked,
    preserveValue = _ref.preserveValue,
    onlyLeafCheck = _ref.onlyLeafCheck,
    _ref$checkable = _ref.checkable,
    checkable = _ref$checkable === void 0 ? true : _ref$checkable,
    selectable = _ref.selectable,
    list = _ref.list,
    defaultValue = _ref.defaultValue,
    value = _ref.value,
    _ref$throttle = _ref.throttle,
    throttle = _ref$throttle === void 0 ? 500 : _ref$throttle,
    onChange = _ref.onChange,
    onSelect = _ref.onSelect,
    _ref$showIcon = _ref.showIcon,
    showIcon = _ref$showIcon === void 0 ? false : _ref$showIcon,
    itemRender = _ref.itemRender,
    props = _objectWithoutProperties(_ref, _excluded);
  var treeRef = useRef(null);
  useImperativeHandle(ref, function () {
    return {
      instance: treeRef.current,
      search: search
    };
  });

  // 扁平化数据, 搜索时需要展开的子级
  var flattenListRef = useRef(null);

  // 搜索关键字
  var keywordRef = useRef(null);

  // 树渲染数据
  var _useState = useState(null),
    _useState2 = _slicedToArray(_useState, 2),
    treeData = _useState2[0],
    setTreeData = _useState2[1];

  // 展开的id
  var _useState3 = useState([]),
    _useState4 = _slicedToArray(_useState3, 2),
    expandedKeys = _useState4[0],
    setExpandedKeys = _useState4[1];
  var expandedKeysRef = useRef([]);

  // 异步已加载项(去掉小箭头项), 只有传入loadData时才生效
  var _useState5 = useState([]),
    _useState6 = _slicedToArray(_useState5, 2),
    loadedKeys = _useState6[0],
    setLoadedKeys = _useState6[1];

  // 更新列表
  useEffect(function () {
    if (!Array.isArray(list) || !list.length) return;

    // 更新平铺的列表, 搜索时使用
    flattenListRef.current = Object.clone(list).flattenTree();

    // 异步加载时需要判断哪些不需要再次加载(isLoaded)
    if (typeof props.loadData === 'function') {
      loadedKeys.push.apply(loadedKeys, _toConsumableArray(getLoadedKeys(flattenListRef.current)));
      setLoadedKeys(_toConsumableArray(new Set(loadedKeys)));
    }

    // 更新渲染列表
    setTreeData(updateTreeData());
    // eslint-disable-next-line
  }, [list]);

  // 展开关键字
  function search(keyword) {
    keywordRef.current = keyword;
    // 没有关键字则没有展开项
    if (!keywordRef.current || Object.isEmptyObject(list)) {
      expandedKeysRef.current = [];
      setExpandedKeys(expandedKeysRef.current);
    } else {
      // 展开的keys
      var newExpandedKeys = getExpandedKeys(keywordRef.current, flattenListRef.current);
      expandedKeysRef.current = newExpandedKeys;
      setExpandedKeys(expandedKeysRef.current);
    }

    // 更新渲染列表
    setTreeData(updateTreeData());
  }

  // 获取更新后的树数据
  function updateTreeData() {
    return getTreeData({
      list: list,
      onlyLeafCheck: onlyLeafCheck,
      keyword: keywordRef.current || '',
      itemRender: itemRender,
      onClick: function onClick(item) {
        // 触发onSelect
        typeof onSelect === 'function' && onSelect(item);

        // 设置展开和收缩项的keys
        if (expandedKeysRef.current.includes(item.id)) {
          expandedKeysRef.current.splice(expandedKeysRef.current.indexOf(item.id), 1);
          setExpandedKeys(_toConsumableArray(expandedKeysRef.current));
        } else {
          expandedKeysRef.current = [item.id].concat(_toConsumableArray(expandedKeysRef.current || []));
          setExpandedKeys(expandedKeysRef.current);
        }
      }
    });
  }

  // 修改
  function handleChange(ids, checkedObject) {
    var _checkedObject$node;
    var checkedNodes = (checkedObject === null || checkedObject === void 0 ? void 0 : checkedObject.checkedNodes) || [];
    // multiple未传则为必选单选
    if (multiple === undefined) {
      if (checkedObject !== null && checkedObject !== void 0 && checkedObject.node) checkedNodes = [checkedObject.node];
    }
    // multiple为false时为可取消单选
    else if (multiple === false) {
      if (checkedNodes.length > 1) {
        if (checkedObject !== null && checkedObject !== void 0 && checkedObject.node) checkedNodes = [checkedObject.node];
      }
    }
    // 多选
    else {
      // 启用半选
      if (enableHalfChecked && Array.isArray(checkedObject.halfCheckedKeys) && checkedObject.halfCheckedKeys.length) {
        var _checkedNodes;
        var halfCheckedNodes = [];
        var _iterator = _createForOfIteratorHelper(flattenListRef.current),
          _step;
        try {
          for (_iterator.s(); !(_step = _iterator.n()).done;) {
            var item = _step.value;
            if (checkedObject.halfCheckedKeys.includes(item.id)) {
              halfCheckedNodes.push(_objectSpread(_objectSpread({}, item), {}, {
                halfChecked: true
              }));
            }
          }
        } catch (err) {
          _iterator.e(err);
        } finally {
          _iterator.f();
        }
        (_checkedNodes = checkedNodes).push.apply(_checkedNodes, halfCheckedNodes);
      }
      // 保留不在树结构中的value
      if (preserveValue && Array.isArray(value) && value.length) {
        var _checkedNodes2;
        var difference = value.filter(function (selectItem) {
          return !flattenListRef.current.some(function (item) {
            return item.id === selectItem.id;
          });
        });
        (_checkedNodes2 = checkedNodes).push.apply(_checkedNodes2, _toConsumableArray(difference));
      }
    }

    // 只级联子级
    if (checkStrictly === 'children' && checkedObject !== null && checkedObject !== void 0 && (_checkedObject$node = checkedObject.node) !== null && _checkedObject$node !== void 0 && _checkedObject$node.id) {
      var _checkedObject$node$i, _checkedObject$node2, _checkedObject$node3;
      var descendants = flattenListRef.current.getFlattenTreeDescendants((_checkedObject$node$i = checkedObject === null || checkedObject === void 0 ? void 0 : (_checkedObject$node2 = checkedObject.node) === null || _checkedObject$node2 === void 0 ? void 0 : _checkedObject$node2.id) !== null && _checkedObject$node$i !== void 0 ? _checkedObject$node$i : '');
      var checked = {};
      var unchecked = {};
      var _loop = function _loop() {
        var descendant = descendants[i];
        // 如果选中项里已经存在此项
        if (checkedNodes.some(function (checkedNode) {
          return descendant.id === checkedNode.id;
        })) {
          checked[descendant.id] = descendant;
        }
        // 不存在的项
        else {
          unchecked[descendant.id] = descendant;
        }
      };
      for (var i = 0; i < descendants.length; i++) {
        _loop();
      }

      // 选中, 将树中选中项, 在值中没有的项加到值中
      if ((checkedObject === null || checkedObject === void 0 ? void 0 : (_checkedObject$node3 = checkedObject.node) === null || _checkedObject$node3 === void 0 ? void 0 : _checkedObject$node3.checked) === false) {
        var _checkedNodes3;
        (_checkedNodes3 = checkedNodes).push.apply(_checkedNodes3, _toConsumableArray(Object.values(unchecked)));
      }
      // 取消选中, 将树中选中项, 将值中存在的选中项清除
      else {
        var checkedIds = Object.keys(checked);
        checkedNodes = checkedNodes.filter(function (item) {
          return !checkedIds.some(function (checkedId) {
            return checkedId === item.id;
          });
        });
      }
    }
    if (onChange) onChange(checkedNodes);
  }

  // 构建选中项
  var checkedKeysProp = useMemo(function () {
    // defaultCheckedKeys|checkedKeys: checkedKeys
    return getCheckedKeysProp(value, defaultValue);
  }, [value, defaultValue]);

  // 异步加载时需要判断哪些不需要再次加载(isLoaded)
  var loadProp = typeof props.loadData === 'function' ? {
    loadedKeys: loadedKeys,
    onLoad: function onLoad(newLoadedKeys) {
      loadedKeys.push.apply(loadedKeys, _toConsumableArray(newLoadedKeys));
      // 异步加载会修改列表, 所以在列表监听处处理loadedKeys即可
    }
  } : {};
  if (!treeData) return null;
  return /*#__PURE__*/_jsx(_Fragment, {
    children: /*#__PURE__*/_jsx(Tree, _objectSpread(_objectSpread(_objectSpread({
      ref: treeRef,
      fieldNames: {
        key: 'id'
      },
      treeData: treeData
      // 异步加载时需要判断哪些不需要再次加载
    }, loadProp), checkedKeysProp), {}, {
      // 选中checkbox
      onCheck: handleChange
      // 展开keys属性
      // 设置了expandedKeys, 就必须有配套的onExpand, 否则将不能再收缩了
      ,
      onExpand: function onExpand(newExpandedKeys) {
        setExpandedKeys(newExpandedKeys);
      }
      // 搜索时展开的子级
      ,
      expandedKeys: expandedKeys
      // 树默认设置
      ,
      showIcon: showIcon,
      onlyLeafCheck: onlyLeafCheck,
      checkStrictly: checkStrictly === false ? false : true,
      checkable: checkable,
      selectable: checkable ? false : true
    }, props))
  });
}
export default /*#__PURE__*/forwardRef(TreePicker);
